#
# spec file for package python-mistletoe
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-mistletoe
Version:        1.4.0
Release:        1.3
Summary:        A Markdown parser in pure Python
License:        MIT
URL:            https://github.com/miyuchina/mistletoe
Source:         https://github.com/miyuchina/mistletoe/archive/refs/tags/v%{version}.tar.gz#/mistletoe-%{version}.tar.gz
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module parameterized}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-Pygments
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A Markdown parser in pure Python, designed to be fast,
spec-compliant and fully customizable.

%prep
%autosetup -p1 -n mistletoe-%{version}
sed -i 's,/usr/bin/env python,,' mistletoe/contrib/md2jira.py
find . -type f -print0 | xargs -0 dos2unix --

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/mistletoe
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative mistletoe

%postun
%python_uninstall_alternative mistletoe

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/mistletoe
%{python_sitelib}/mistletoe
%{python_sitelib}/mistletoe-%{version}.dist-info

%changelog
* Wed Oct 23 2024 Dirk Müller <dmueller@suse.com>
- update to 1.4.0:
  * Add `parent` attribute/property (#71 via #206).
  * `MarkdownRenderer`: Keep the original content spacing before
    the list marker (#213 via #215).
  * Bump build/CI scripts.
* Wed Feb  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * Add line numbers (`line_number` attribute) on all _block_
    tokens during parsing (#188).
  * More thorough documentation and explanation of AST and tokens
    in the Developer's Guide (within #188).
  * `HtmlRenderer`: Option to skip HTML tokens parsing (#74 via
    [#204]). Just pass `process_html_tokens=False` to the
    renderer's constructor.
  * `LaTeXRenderer`: Add AMS packages for Math (#207).
  * `MarkdownRenderer`: Penultimate lines of multiline fragments
    being ignored (#201).
  * `MathJaxRenderer`: Output inline math (in: `$...$`) correctly
    (out: `\(...\)`) (#195).
  * Make local installation work again with pip 23.2 and above
  * `MarkdownRenderer`: Keep the original content spacing after
    the list marker (#196 via #197).
  * The old behavior can be enforced by passing
    `normalize_whitespace=True` to the renderer's constructor
  * Provided you create `ListItem`'s tokens directly via its
    constructor, you need to pass it a new parameter called
    `indentation` (number of spaces before the item marker):
* Thu Dec 14 2023 Elisei Roca <eroca@mailbox.org>
- Switch to Github for sources as they include all tests
- Run dos2unix for E: wrong-script-end-of-line-encoding
* Sun Dec 10 2023 Elisei Roca <eroca@mailbox.org>
- Update to version 1.2.1:
  https://github.com/miyuchina/mistletoe/compare/v1.0.1...v1.2.1
* Sun Apr 30 2023 Xu Zhao <i@xuzhao.net>
- Upgrade to 1.0.1.
* Wed Jun  8 2022 Xu Zhao <i@xuzhao.net>
- Initial version. v0.8.2.
